@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import hashlib
+import select
 
 import os
 from os import path
@@ -211,24 +212,32 @@ class process(StdoutableProcess):
         return self.cacheerr
 
     def readByLine(self):
+        _cacheerr = []
         try:
             self._open()
             if self.cacheresult is None:
-                s = self.pipe.stdout.readline()
-                while s:
-                    yield s
-                    self._cachedata.append(s)
-                    s = self.pipe.stdout.readline()
-                if self.pipe.stderr:
-                    self.cacheerr = self.pipe.stderr.read()
-                else:
-                    self.cacheerr = ""
+                _stdout = self.pipe.stdout.fileno()
+                _stderr = self.pipe.stderr.fileno()
+                reads = [_stdout, _stderr]
+                while True:
+                    ret = select.select(reads, [], [])
+                    for fd in ret[0]:
+                        if fd == _stdout:
+                            s = self.pipe.stdout.readline()
+                            yield s
+                            self._cachedata.append(s)
+                        if fd == _stderr:
+                            s = self.pipe.stderr.readline()
+                            _cacheerr.append(s)
+                    if self.pipe.poll() is not None:
+                        break
         except KeyboardInterrupt:
             self.kill()
             raise KeyboardInterrupt
         finally:
             if self.cacheresult is None:
                 self.cacheresult = "\n".join(self._cachedata)
+            self.cacheerr = "".join(_cacheerr)
             self.close()
 
     def read(self):
@@ -861,16 +870,14 @@ def getCmdLineParam(paramName):
 from device import getUUIDDict
 import device
 
-
-class FStab(object):
+class MountHelper(object):
     """Data reader for fstab"""
-    __metaclass__ = SingletonParam
-    fstab_file = '/etc/fstab'
+    data_file = '/etc/fstab'
     NAME, DIR, TYPE, OPTS, FREQ, PASSNO = range(0, 6)
 
-    def __init__(self, fstab_file=None, devs=()):
-        if fstab_file:
-            self.fstab_file = fstab_file
+    def __init__(self, data_file=None, devs=()):
+        if data_file:
+            self.data_file = data_file
         self.cache = []
         self.rotateCache = []
         self.dictUUID = getUUIDDict(devs=devs)
@@ -885,7 +892,7 @@ class FStab(object):
         self.cache = \
             map(lambda x: setlen(map(lambda y: y.strip(), x.split())),
                 filter(lambda x: x.strip() and not x.lstrip().startswith("#"),
-                       open(self.fstab_file, 'r').read().split('\n')))
+                       open(self.data_file, 'r').read().split('\n')))
         for data in self.cache:
             convertDev = lambda x: path.realpath(x) if x.startswith('/') else x
             data[0] = device.getUdevDeviceInfo(
@@ -895,12 +902,14 @@ class FStab(object):
         self.rotateCache = zip(*self.cache)
 
     def getBy(self, what=DIR, where=NAME, _in=None, eq=None,
-              noteq=None, allentry=False):
+              contains=None, noteq=None, allentry=False):
         """Get data from fstab"""
         if eq is not None:
             filterfunc = lambda x: x[where] == eq
         elif _in is not None:
-            filterfunc = lambda x: _in in x[where]
+            filterfunc = lambda x: x[where] in _in
+        elif contains is not None:
+            filterfunc = lambda x: contains in x[where]
         else:
             filterfunc = lambda x: x[where] != noteq
         res = map(lambda x: x[what], filter(filterfunc, self.cache))
@@ -921,6 +930,15 @@ class FStab(object):
             filterfunc = lambda x: x[what] != noteq
         return bool(filter(filterfunc, self.cache))
 
+class FStab(MountHelper):
+    """Data reader for fstab"""
+    __metaclass__ = SingletonParam
+    data_file = '/etc/fstab'
+
+class Mounts(MountHelper):
+    """Data reader for fstab"""
+    data_file = '/etc/mtab'
+
 
 def tarLinks(rootpath, archpath, skip=()):
     """
